#
# This file contains 'Framework Code' and is licensed as such
# under the terms of your license agreement with Intel or your
# vendor.  This file may not be modified, except as allowed by
# additional terms of your license agreement.
#
## @file
# N2x00 platform with 32-bit DXE for 1MB flash devices.
#
# This package provides N2x00 platform specific modules.
# Copyright (c) 2010-2012, Intel Corporation.
#
# All rights reserved.
#    This software and associated documentation (if any) is furnished
#    under a license and may only be used or copied in accordance
#    with the terms of the license. Except as permitted by such
#    license, no part of this software or documentation may be
#    reproduced, stored in a retrieval system, or transmitted in any
#    form or by any means without the express written consent of
#    Intel Corporation.
#
##

################################################################################
#
# Defines Section - statements that will be processed to create a Makefile.
#
################################################################################
[Defines]
  PLATFORM_NAME                  = CedarRockPlatformPkg
  PLATFORM_GUID                  = 1BEDB57A-7904-406e-8486-C89FC7FB39EE
  VPD_TOOL_GUID                  = 8C3D856A-9BE6-468E-850A-24F7A8D38E08
  PLATFORM_VERSION               = 0.1
  DSC_SPECIFICATION              = 0x00010005
  OUTPUT_DIRECTORY               = Build/CedarRockPlatform
  SUPPORTED_ARCHITECTURES        = IA32
  BUILD_TARGETS                  = DEBUG|RELEASE
  SKUID_IDENTIFIER               = DEFAULT
  FLASH_DEFINITION               = CedarRockPlatformPkg/CedarRockPlatformPkg.fdf
  DEFINE PLATFORM_PACKAGE        = CedarRockPlatformPkg
  DEFINE PROJECT_TPT_ROOT        = IchTpt
  DEFINE PROJECT_CV_ROOT         = CedarView
  DEFINE PROJECT_PPM_ROOT        = CedarRockPlatformPkg/PowerManagement
  DEFINE PROJECT_CV_FAMILY       = CV
  DEFINE PROJECT_TPT_FAMILY      = IntelIch
  DEFINE PLATFORM_PCIEXPRESS_BASE = 0E0000000
  DEFINE PLATFORM_PCIEXPRESS_LEN = 10000000

!include CedarRockPlatformPkg/features.txt

################################################################################
#
# SKU Identification section - list of all SKU IDs supported by this
#                              Platform.
#
################################################################################
[SkuIds]
  0|DEFAULT              # The entry: 0|DEFAULT is reserved and always required.

################################################################################
#
# Library Class section - list of all Library Classes needed by this Platform.
#
################################################################################
[LibraryClasses]
  #
  # Entry point
  #
  PeiCoreEntryPoint|MdePkg/Library/PeiCoreEntryPoint/PeiCoreEntryPoint.inf
  PeimEntryPoint|MdePkg/Library/PeimEntryPoint/PeimEntryPoint.inf
  DxeCoreEntryPoint|MdePkg/Library/DxeCoreEntryPoint/DxeCoreEntryPoint.inf
  UefiDriverEntryPoint|MdePkg/Library/UefiDriverEntryPoint/UefiDriverEntryPoint.inf
  UefiApplicationEntryPoint|MdePkg/Library/UefiApplicationEntryPoint/UefiApplicationEntryPoint.inf
  #
  # Basic
  #
  BaseLib|MdePkg/Library/BaseLib/BaseLib.inf
  SynchronizationLib|MdePkg/Library/BaseSynchronizationLib/BaseSynchronizationLib.inf
  BaseMemoryLib|MdePkg/Library/BaseMemoryLibRepStr/BaseMemoryLibRepStr.inf
  PrintLib|MdePkg/Library/BasePrintLib/BasePrintLib.inf
  CpuLib|MdePkg/Library/BaseCpuLib/BaseCpuLib.inf
  IoLib|MdePkg/Library/BaseIoLibIntrinsic/BaseIoLibIntrinsic.inf
  PciLib|MdePkg/Library/BasePciLibCf8/BasePciLibCf8.inf
  PciCf8Lib|MdePkg/Library/BasePciCf8Lib/BasePciCf8Lib.inf
  PciExpressLib|MdePkg/Library/BasePciExpressLib/BasePciExpressLib.inf
  CacheMaintenanceLib|MdePkg/Library/BaseCacheMaintenanceLib/BaseCacheMaintenanceLib.inf
  PeCoffLib|MdePkg/Library/BasePeCoffLib/BasePeCoffLib.inf
!if $(CFG_SOURCE_DEBUG) == 1
  PeCoffExtraActionLib|SourceLevelDebugPkg/Library/PeCoffExtraActionLibDebug/PeCoffExtraActionLibDebug.inf
  LocalApicLib|UefiCpuPkg/Library/BaseXApicLib/BaseXApicLib.inf
!else
  PeCoffExtraActionLib|MdePkg/Library/BasePeCoffExtraActionLibNull/BasePeCoffExtraActionLibNull.inf
!endif
  PeCoffGetEntryPointLib|MdePkg/Library/BasePeCoffGetEntryPointLib/BasePeCoffGetEntryPointLib.inf
  #
  # UEFI & PI
  #
  UefiBootServicesTableLib|MdePkg/Library/UefiBootServicesTableLib/UefiBootServicesTableLib.inf
  UefiRuntimeServicesTableLib|MdePkg/Library/UefiRuntimeServicesTableLib/UefiRuntimeServicesTableLib.inf
  UefiRuntimeLib|MdePkg/Library/UefiRuntimeLib/UefiRuntimeLib.inf
  UefiLib|MdePkg/Library/UefiLib/UefiLib.inf
  UefiHiiServicesLib|MdeModulePkg/Library/UefiHiiServicesLib/UefiHiiServicesLib.inf
  HiiLib|MdeModulePkg/Library/UefiHiiLib/UefiHiiLib.inf
  DevicePathLib|MdePkg/Library/UefiDevicePathLib/UefiDevicePathLib.inf
  UefiDecompressLib|IntelFrameworkModulePkg/Library/BaseUefiTianoCustomDecompressLib/BaseUefiTianoCustomDecompressLib.inf
  PeiServicesTablePointerLib|MdePkg/Library/PeiServicesTablePointerLibIdt/PeiServicesTablePointerLibIdt.inf
  PeiServicesLib|MdePkg/Library/PeiServicesLib/PeiServicesLib.inf
  DxeServicesLib|MdePkg/Library/DxeServicesLib/DxeServicesLib.inf
  DxeServicesTableLib|MdePkg/Library/DxeServicesTableLib/DxeServicesTableLib.inf
  UefiCpuLib|UefiCpuPkg/Library/BaseUefiCpuLib/BaseUefiCpuLib.inf
  #
  # Framework
  #
  #
  # Generic Modules
  #
  UefiUsbLib|MdePkg/Library/UefiUsbLib/UefiUsbLib.inf
  UefiScsiLib|MdePkg/Library/UefiScsiLib/UefiScsiLib.inf
  NetLib|MdeModulePkg/Library/DxeNetLib/DxeNetLib.inf
  IpIoLib|MdeModulePkg/Library/DxeIpIoLib/DxeIpIoLib.inf
  UdpIoLib|MdeModulePkg/Library/DxeUdpIoLib/DxeUdpIoLib.inf
  DpcLib|MdeModulePkg/Library/DxeDpcLib/DxeDpcLib.inf
  OemHookStatusCodeLib|MdeModulePkg/Library/OemHookStatusCodeLibNull/OemHookStatusCodeLibNull.inf
  SecurityManagementLib|MdeModulePkg/Library/DxeSecurityManagementLib/DxeSecurityManagementLib.inf
  #
  # CPU
  #
  MtrrLib|UefiCpuPkg/Library/MtrrLib/MtrrLib.inf
  #
  # CV
  #
  #
  # IOH
  #
  #
  # Peripheral & Flash
  #
  SerialPortLib|$(PLATFORM_PACKAGE)/Library/SerialPortLib/SerialPortLib.inf
  #
  # Platform
  #
  TimerLib|$(PLATFORM_PACKAGE)/Library/IntelIchAcpiTimerLib/IntelIchAcpiTimerLib.inf
  #
  # Misc
  #
!if $(CFG_DEBUG) == 1
  DebugLib|MdePkg/Library/BaseDebugLibSerialPort/BaseDebugLibSerialPort.inf
!else
  DebugLib|MdePkg/Library/BaseDebugLibNull/BaseDebugLibNull.inf
!endif
  PerformanceLib|MdeModulePkg/Library/DxePerformanceLib/DxePerformanceLib.inf
!if $(CFG_SOURCE_DEBUG) == 1
  DebugCommunicationLib|$(PLATFORM_PACKAGE)/Override/DebugCommunicationLibSerialPort/DebugCommunicationLibSerialPort.inf
!else
  DebugAgentLib|MdeModulePkg/Library/DebugAgentLibNull/DebugAgentLibNull.inf
!endif

[LibraryClasses.IA32.PEIM,LibraryClasses.IA32.PEI_CORE,LibraryClasses.IA32.SEC]
  #
  # SEC and PEI phase common
  #
  PcdLib|MdePkg/Library/PeiPcdLib/PeiPcdLib.inf
  HobLib|MdePkg/Library/PeiHobLib/PeiHobLib.inf
  MemoryAllocationLib|MdePkg/Library/PeiMemoryAllocationLib/PeiMemoryAllocationLib.inf
!if $(CFG_STATUSCODE) == 1
  ReportStatusCodeLib|MdeModulePkg/Library/PeiReportStatusCodeLib/PeiReportStatusCodeLib.inf
!else
  ReportStatusCodeLib|MdePkg/Library/BaseReportStatusCodeLibNull/BaseReportStatusCodeLibNull.inf
!endif
  ExtractGuidedSectionLib|MdePkg/Library/PeiExtractGuidedSectionLib/PeiExtractGuidedSectionLib.inf
  PerformanceLib|MdeModulePkg/Library/PeiPerformanceLib/PeiPerformanceLib.inf
!if $(CFG_SOURCE_DEBUG) == 1
  DebugAgentLib|$(PLATFORM_PACKAGE)/Override/DebugAgent/SecPeiDebugAgentLib.inf
!endif
[LibraryClasses.IA32.SEC]
  #
  # SEC specific phase
  #
  DebugLib|MdePkg/Library/BaseDebugLibNull/BaseDebugLibNull.inf
  PcdLib|MdePkg/Library/BasePcdLibNull/BasePcdLibNull.inf

[LibraryClasses.IA32]
  #
  # DXE phase common
  #
  PcdLib|MdePkg/Library/DxePcdLib/DxePcdLib.inf
  HobLib|MdePkg/Library/DxeHobLib/DxeHobLib.inf
  MemoryAllocationLib|MdePkg/Library/UefiMemoryAllocationLib/UefiMemoryAllocationLib.inf
!if $(CFG_STATUSCODE) == 1
  ReportStatusCodeLib|MdeModulePkg/Library/DxeReportStatusCodeLib/DxeReportStatusCodeLib.inf
!else
  ReportStatusCodeLib|MdePkg/Library/BaseReportStatusCodeLibNull/BaseReportStatusCodeLibNull.inf
!endif
  ExtractGuidedSectionLib|MdePkg/Library/DxeExtractGuidedSectionLib/DxeExtractGuidedSectionLib.inf
!if $(CFG_SOURCE_DEBUG) == 1
  DebugAgentLib|$(PLATFORM_PACKAGE)/Override/DebugAgent/DxeDebugAgentLib.inf
!endif

[LibraryClasses.IA32.DXE_CORE]
  HobLib|MdePkg/Library/DxeCoreHobLib/DxeCoreHobLib.inf
  MemoryAllocationLib|MdeModulePkg/Library/DxeCoreMemoryAllocationLib/DxeCoreMemoryAllocationLib.inf
  PerformanceLib|MdeModulePkg/Library/DxeCorePerformanceLib/DxeCorePerformanceLib.inf

[LibraryClasses.IA32.DXE_SMM_DRIVER]
  SmmServicesTableLib|MdePkg/Library/SmmServicesTableLib/SmmServicesTableLib.inf
!if $(CFG_STATUSCODE) == 1
  ReportStatusCodeLib|MdeModulePkg/Library/SmmReportStatusCodeLib/SmmReportStatusCodeLib.inf
!else
  ReportStatusCodeLib|MdePkg/Library/BaseReportStatusCodeLibNull/BaseReportStatusCodeLibNull.inf
!endif
  MemoryAllocationLib|MdePkg/Library/SmmMemoryAllocationLib/SmmMemoryAllocationLib.inf
!if $(CFG_SOURCE_DEBUG) == 1
  DebugAgentLib|$(PLATFORM_PACKAGE)/Override/DebugAgent/SmmDebugAgentLib.inf
!endif


[LibraryClasses.IA32.SMM_CORE]
  SmmServicesTableLib|MdeModulePkg/Library/PiSmmCoreSmmServicesTableLib/PiSmmCoreSmmServicesTableLib.inf
!if $(CFG_STATUSCODE) == 1
  ReportStatusCodeLib|MdeModulePkg/Library/SmmReportStatusCodeLib/SmmReportStatusCodeLib.inf
!else
  ReportStatusCodeLib|MdePkg/Library/BaseReportStatusCodeLibNull/BaseReportStatusCodeLibNull.inf
!endif
  MemoryAllocationLib|MdeModulePkg/Library/PiSmmCoreMemoryAllocationLib/PiSmmCoreMemoryAllocationLib.inf

[LibraryClasses.IA32.DXE_RUNTIME_DRIVER]
!if $(CFG_STATUSCODE) == 1
  ReportStatusCodeLib|MdeModulePkg/Library/RuntimeDxeReportStatusCodeLib/RuntimeDxeReportStatusCodeLib.inf
!else
  ReportStatusCodeLib|MdePkg/Library/BaseReportStatusCodeLibNull/BaseReportStatusCodeLibNull.inf
!endif

[LibraryClasses.IA32.UEFI_DRIVER,LibraryClasses.IA32.UEFI_APPLICATION]
!if $(CFG_DEBUG) == 1
  DebugLib|MdePkg/Library/UefiDebugLibStdErr/UefiDebugLibStdErr.inf
  DebugLibConOut|MdePkg/Library/UefiDebugLibConOut/UefiDebugLibConOut.inf
!else
  DebugLib|MdePkg/Library/BaseDebugLibNull/BaseDebugLibNull.inf
!endif
  PcdLib|MdePkg/Library/BasePcdLibNull/BasePcdLibNull.inf

################################################################################
#
# Pcd Section - list of all EDK II PCD Entries defined by this Platform
#
################################################################################
[PcdsFeatureFlag]
  #gEfiMdeModulePkgTokenSpaceGuid.PcdSupportUpdateCapsuleReset|TRUE
  gEfiMdeModulePkgTokenSpaceGuid.PcdDxeIplSwitchToLongMode|FALSE
  gEfiTianoModulePkgTokenSpaceGuid.PcdSecStartLocalApicTimer|TRUE
  gEfiCpuTokenSpaceGuid.PcdCpuPrescottFamilyFlag|FALSE
  gEfiCpuTokenSpaceGuid.PcdCpuCedarMillFamilyFlag|FALSE
  gEfiCpuTokenSpaceGuid.PcdCpuConroeFamilyFlag|FALSE
  gEfiCpuTokenSpaceGuid.PcdCpuE6xxFamilyFlag|FALSE
  gEfiCpuTokenSpaceGuid.PcdCpuCedarViewFamilyFlag|TRUE
  gEfiCpuTokenSpaceGuid.PcdCpuThermalManagementFlag|FALSE
  gEfiCpuTokenSpaceGuid.PcdCpuEnhancedCStateFlag|TRUE
  gEfiCpuTokenSpaceGuid.PcdCpuPeciFlag|FALSE
  gEfiCpuTokenSpaceGuid.PcdCpuHardwarePrefetcherFlag|FALSE
  gEfiCpuTokenSpaceGuid.PcdCpuAdjacentCacheLinePrefetchFlag|FALSE
  gEfiCpuTokenSpaceGuid.PcdCpuDcuPrefetcherFlag|FALSE
  gEfiCpuTokenSpaceGuid.PcdCpuIpPrefetcherFlag|FALSE
  gEfiCpuTokenSpaceGuid.PcdCpuSmrrFlag|TRUE
  gEfiCpuTokenSpaceGuid.PcdCpuFastStringFlag|TRUE
  gEfiCpuTokenSpaceGuid.PcdCpuEistFlag|TRUE
  gEfiMdeModulePkgTokenSpaceGuid.PcdPciBusHotplugDeviceSupport|FALSE
  gEfiMdeModulePkgTokenSpaceGuid.PcdInstallAcpiSdtProtocol|TRUE
  gEfiTianoModulePkgTokenSpaceGuid.PcdPlatformCsmSupport|FALSE

[PcdsFixedAtBuild]
  !if $(TARGET) == "RELEASE"
  gEfiMdePkgTokenSpaceGuid.PcdDebugPropertyMask|0x0
  gEfiMdePkgTokenSpaceGuid.PcdReportStatusCodePropertyMask|0x0
  gEfiMdePkgTokenSpaceGuid.PcdPostCodePropertyMask|0x0
  !else
  gEfiMdePkgTokenSpaceGuid.PcdDebugPropertyMask|0x27
  ## The mask is used to control ReportStatusCodeLib behavior, the bit defintion can refer to MdePkg/Include/Library/ReportStatusCodeLib.h
  gEfiMdePkgTokenSpaceGuid.PcdReportStatusCodePropertyMask|0x06
  gEfiMdePkgTokenSpaceGuid.PcdPostCodePropertyMask|0x18
  !endif

  # turn on performance measurement support
  gEfiMdePkgTokenSpaceGuid.PcdPerformanceLibraryPropertyMask|0x01
  gEfiMdeModulePkgTokenSpaceGuid.PcdMaxPeiPerformanceLogEntries|40

  gEfiMdeModulePkgTokenSpaceGuid.PcdLoadModuleAtFixAddressEnable|0
  gEfiCpuTokenSpaceGuid.PcdTemporaryRamSize|0x4000
  gPcAtChipsetPkgTokenSpaceGuid.Pcd8259LegacyModeMask|0x0eB8
  gEfiMdePkgTokenSpaceGuid.PcdPciExpressBaseAddress|0xE0000000
  gEfiMdeModulePkgTokenSpaceGuid.PcdMaxVariableSize|0x2000
  gEfiMdeModulePkgTokenSpaceGuid.PcdHwErrStorageSize|0x00002000
  gEfiMdeModulePkgTokenSpaceGuid.PcdMaxHardwareErrorVariableSize|0x1000
  gEfiCpuTokenSpaceGuid.PcdCpuMicrocodePatchAddress|0xFFFCA000
  gEfiCpuTokenSpaceGuid.PcdCpuNumberOfMicrocodePatches|4
  gEfiCpuTokenSpaceGuid.PcdPlatformType|1
  gEfiCpuTokenSpaceGuid.PcdPlatformCpuMaxCoreFrequency|3800
  gEfiCpuTokenSpaceGuid.PcdPlatformCpuMaxFsbFrequency|1066
  gEfiN2x00TokenSpaceGuid.PcdFlashCVMicrocodeBase|0xFFFB0000

  gEfiSioTokenSpaceGuid.PcdSerialRegisterBase|0x3f8
  gEfiSioTokenSpaceGuid.PcdSioEnableSerialPort1|TRUE
  gEfiMdePkgTokenSpaceGuid.PcdUartDefaultBaudRate|115200
  gEfiMdePkgTokenSpaceGuid.PcdUartDefaultDataBits|8
  gEfiMdePkgTokenSpaceGuid.PcdUartDefaultParity|1
  gEfiMdePkgTokenSpaceGuid.PcdUartDefaultStopBits|1
  gEfiMdePkgTokenSpaceGuid.PcdDefaultTerminalType|0

[PcdsPatchableInModule]
  gEfiMdePkgTokenSpaceGuid.PcdDebugPrintErrorLevel|0x80000042
  gEfiTianoModulePkgTokenSpaceGuid.PcdLegacyBiosCacheLegacyRegion|FALSE

[PcdsDynamicExHii.common.DEFAULT]
  gEfiIntelFrameworkModulePkgTokenSpaceGuid.PcdPlatformBootTimeOut|L"Timeout"|gEfiGlobalVariableGuid|0x0|5
  gEfiIntelFrameworkModulePkgTokenSpaceGuid.PcdBootState|L"BootState"|gCedarTrailPlatformTokenSpaceGuid|0x0|TRUE

[PcdsDynamicExDefault.common.DEFAULT]
  gEfiCpuTokenSpaceGuid.PcdCpuProcessorFeatureUserConfiguration|0xffffffff
  gEfiTianoModulePkgTokenSpaceGuid.PcdS3BootScriptTablePrivateDataPtr|0x0

  # CedarviewPkg.dec
  gEfiN2x00TokenSpaceGuid.PcdPlatformSmbusAddrNum|0x0
  gEfiN2x00TokenSpaceGuid.PcdPlatformSmbusAddrTable|0x0
  gEfiN2x00TokenSpaceGuid.PcdCVDeviceEnables|0xFFFFFFFF
  gEfiN2x00TokenSpaceGuid.PcdCVAzaliaConfig|0x02
  gEfiN2x00TokenSpaceGuid.PcdCVPcieRootPortConfiguration|{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}

  # IntelFrameworkModulePkg.dec
  gEfiIntelFrameworkModulePkgTokenSpaceGuid.PcdHardwareErrorRecordLevel|0

  # IA32FamilyCpuPkg
  gEfiCpuTokenSpaceGuid.PcdIsPowerOnReset|FALSE
  gEfiCpuTokenSpaceGuid.PcdPlatformCpuAssetTags|0x0
  gEfiCpuTokenSpaceGuid.PcdPlatformCpuSocketNames|0x0
  gEfiCpuTokenSpaceGuid.PcdPlatformCpuFrequencyLists|0x0
  gEfiCpuTokenSpaceGuid.PcdCpuConfigContextBuffer|0x0
  gEfiCpuTokenSpaceGuid.PcdCpuMtrrTableAddress|0x0
  gEfiCpuTokenSpaceGuid.PcdCpuPageTableAddress|0x0
  gEfiCpuTokenSpaceGuid.PcdCpuProcessorFeatureSetting|0x0
  gEfiCpuTokenSpaceGuid.PcdCpuProcessorFeatureCapability|0x0
  gEfiCpuTokenSpaceGuid.PcdCpuCallbackSignal|0x0

[PcdsDynamicExVpd.common.DEFAULT]
  gEfiN2x00TokenSpaceGuid.PcdCVSignZero | 0x0 | 0x40
  gEfiN2x00TokenSpaceGuid.PcdCVSignOne | 0x1 | 0x43
  gEfiN2x00TokenSpaceGuid.PcdCVSignTwo | 0x2 | 0x56
  gEfiN2x00TokenSpaceGuid.PcdCVSignThree | 0x3 | 0x40
  gEfiN2x00TokenSpaceGuid.PcdIgdPreAllocSize | 0x4 | 0x02
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort2InternalConnectorType | 0x5 | 0x0F
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable9Enable | 0x6 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable8Polarity | 0x7 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort4InternalConnectorType | 0x8 | 0xFF
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable0SourceIrq | 0x9 | 0x00
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort10ExternalConnectorType | 0xa | 0x12
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot6Type | 0xb | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable11TrigerMode | 0xc | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable11SourceIrq | 0xd | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort9ExternalConnectorType | 0xe | 0x12
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSChassisElementCount | 0xf | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDeviceInfoNumber | 0x10 | 0x5
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable2Enable | 0x11 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSChassisBootupState | 0x12 | 0x03
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot5DataBusWidth | 0x13 | 0x5
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable1SourceIrq | 0x14 | 0x09
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable8TrigerMode | 0x15 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdLocalApicSettingAddressOverrideEnable | 0x16 | 0x00
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot12Type | 0x17 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSConnectorNumber | 0x18 | 16
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot14Type | 0x19 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable8Enable | 0x1a | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot12Usage | 0x1b | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot7Usage | 0x1c | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort8ExternalConnectorType | 0x1d | 0x12
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot4Type | 0x1e | 0xA5
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable6SourceIrq | 0x1f | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable5SourceIrq | 0x20 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot5Length | 0x21 | 0x4
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable15TrigerMode | 0x22 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot12DataBusWidth | 0x23 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot4DataBusWidth | 0x24 | 0x5
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable12Enable | 0x25 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable14TrigerMode | 0x26 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable14SourceIrq | 0x27 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort12ExternalConnectorType | 0x28 | 0x0B
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable4TrigerMode | 0x29 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable5Enable | 0x2a | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort12InternalConnectorType | 0x2b | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable3Enable | 0x2c | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot9Type | 0x2d | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort1InternalConnectorType | 0x2e | 0x0F
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable6Polarity | 0x2f | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable3SourceIrq | 0x30 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort1ExternalConnectorType | 0x31 | 0x0F
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot9Length | 0x32 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort5Type | 0x33 | 0x09
  gCedarTrailPlatformTokenSpaceGuid.PcdIoApicSettingIoApicId | 0x34 | 0x08
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort7ExternalConnectorType | 0x35 | 0x04
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot3Type | 0x36 | 0xA5
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable4Enable | 0x37 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable5Polarity | 0x38 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable7TrigerMode | 0x39 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort9Type | 0x3a | 0x10
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort10InternalConnectorType | 0x3b | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort14Type | 0x3c | 0xFF
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort14InternalConnectorType | 0x3d | 0x16
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort1Type | 0x3e | 0x0D
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort2ExternalConnectorType | 0x3f | 0x0F
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot7DataBusWidth | 0x40 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable1Enable | 0x41 | 0x01
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable12Polarity | 0x42 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot2Type | 0x43 | 0xA5
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable6TrigerMode | 0x44 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort11ExternalConnectorType | 0x45 | 0x12
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort9InternalConnectorType | 0x46 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable1TrigerMode | 0x47 | 0x03
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable11Enable | 0x48 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable0Enable | 0x49 | 0x01
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSChassisPowerSupplyState | 0x4a | 0x03
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort13InternalConnectorType | 0x4b | 0x17
  gCedarTrailPlatformTokenSpaceGuid.PcdLocalApicSettingPolarity | 0x4c | 0x01
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort15Type | 0x4d | 0xFF
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot2Length | 0x4e | 0x4
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable13TrigerMode | 0x4f | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable2Polarity | 0x50 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable14Enable | 0x51 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable9Polarity | 0x52 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort3ExternalConnectorType | 0x53 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot8Length | 0x54 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot6DataBusWidth | 0x55 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort10Type | 0x56 | 0x10
  gCedarTrailPlatformTokenSpaceGuid.PcdBDsBootSilentEnable | 0x57 | 0
  gCedarTrailPlatformTokenSpaceGuid.PcdBdsDelay | 0x58 |0x00
  gCedarTrailPlatformTokenSpaceGuid.PcdBootOrderPolicyEnable | 0x59 | 1
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot14DataBusWidth | 0x5a | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable7SourceIrq | 0x5b | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort16ExternalConnectorType | 0x5c | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSBiosCharEx1 | 0x5d | 0x03
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot13Usage | 0x5e | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort7Type | 0x5f | 0x05
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot5Usage | 0x60 | 0x3
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable12TrigerMode | 0x61 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort8InternalConnectorType | 0x62 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSChassisSecurityState | 0x63 | 0x01
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort3InternalConnectorType | 0x64 | 0xFF
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort11InternalConnectorType | 0x65 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable10SourceIrq | 0x66 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable13SourceIrq | 0x67 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot6Length | 0x68 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot4Usage | 0x69 | 0x3
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot3Usage | 0x6a | 0x3
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable12SourceIrq | 0x6b | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort8Type | 0x6c | 0x10
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSBiosCharEx2 | 0x6d | 0x03
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot6Usage | 0x6e | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot10Usage | 0x6f | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdLocalApicSettingLocalApicLint | 0x70 | 0x01
  gCedarTrailPlatformTokenSpaceGuid.PcdLocalApicSettingTrigerMode | 0x71 | 0x03
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable9SourceIrq | 0x72 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot1Type | 0x73 | 0x6
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot13Length | 0x74 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable7Enable | 0x75 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort13Type | 0x76 | 0xFF
  gCedarTrailPlatformTokenSpaceGuid.PcdIoApicSettingTrigerMode | 0x77 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlotNumber | 0x78 | 5
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot9Usage | 0x79 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable4SourceIrq | 0x7a | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable10Polarity | 0x7b | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot1Length | 0x7c | 0x4
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort13ExternalConnectorType | 0x7d | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSChassisNumberPowerCords | 0x7e | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable13Enable | 0x7f | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable10Enable | 0x80 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable14Polarity | 0x81 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot5Type | 0x82 | 0xA5
  gCedarTrailPlatformTokenSpaceGuid.PcdIoApicSettingNmiEnable | 0x83 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort14ExternalConnectorType | 0x84 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort16InternalConnectorType | 0x85 | 0x16
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable0TrigerMode | 0x86 | 0x00
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot9DataBusWidth | 0x87 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort12Type | 0x88 | 0x1F
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort4Type | 0x89 | 0x09
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable8SourceIrq | 0x8a | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort5InternalConnectorType | 0x8b | 0xFF
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot4Length | 0x8c | 0x4
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot8Usage | 0x8d | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable5TrigerMode | 0x8e | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable4Polarity | 0x8f | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot7Length | 0x90 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot8DataBusWidth | 0x91 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot10Length | 0x92 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable9TrigerMode | 0x93 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable15Polarity | 0x94 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdIoApicSettingNmiSource | 0x95 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot8Type | 0x96 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable2TrigerMode | 0x97 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort6InternalConnectorType | 0x98 | 0xFF
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable3Polarity | 0x99 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot11DataBusWidth | 0x9a | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable7Polarity | 0x9b | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable15Enable | 0x9c | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot10Type | 0x9d | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort2Type | 0x9e | 0x0E
  gCedarTrailPlatformTokenSpaceGuid.PcdIoApicSettingPolarity | 0x9f | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable15SourceIrq | 0xa0 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot2Usage | 0xa1 | 0x3
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot11Type | 0xa2 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable13Polarity | 0xa3 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort3Type | 0xa4 | 0x09
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot1Usage | 0xa5 | 0x3
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort6ExternalConnectorType | 0xa6 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot14Usage | 0xa7 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSChassisHeight | 0xa8 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot14Length | 0xa9 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort5ExternalConnectorType | 0xaa | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort7InternalConnectorType | 0xab | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable11Polarity | 0xac | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort15ExternalConnectorType | 0xad | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot1DataBusWidth | 0xae | 0x5
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSChassisElementRecordLength | 0xaf | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot13Type | 0xb0 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot3Length | 0xb1 | 0x4
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort15InternalConnectorType | 0xb2 | 0x16
  gCedarTrailPlatformTokenSpaceGuid.PcdLocalApicSettingNmiEnabelApicIdMask | 0xb3 | 0x0F
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort16Type | 0xb4 | 0xFF
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot7Type | 0xb5 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot10DataBusWidth | 0xb6 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable2SourceIrq | 0xb7 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort6Type | 0xb8 | 0x09
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable6Enable | 0xb9 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable0Polarity | 0xba | 0x00
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot12Length | 0xbb | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSChassisType | 0xbc | 0x00000003
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable1Polarity | 0xbd | 0x01
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort4ExternalConnectorType | 0xbe | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot3DataBusWidth | 0xbf | 0x5
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot13DataBusWidth | 0xc0 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot11Length | 0xc1 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot2DataBusWidth | 0xc2 | 0x5
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot11Usage | 0xc3 | 0x2
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable3TrigerMode | 0xc4 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable10TrigerMode | 0xc5 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort11Type | 0xc6 | 0x10
  gCedarTrailPlatformTokenSpaceGuid.PcdBootOrderHD | 0xc7 | 1
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot14Id | 0xc9 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot4Id | 0xcb | 0x04
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot2Id | 0xcd | 0x02
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot12Id | 0xcf | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot3Id | 0xd1 | 0x03
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot10Id | 0xd3 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot13Id | 0xd5 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot11Id | 0xd7 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdBootOrderUsb | 0xd9 | 4
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot8Id | 0xdb | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot1Id | 0xdd | 0x01
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot7Id | 0xdf | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSBiosStartAddress | 0xe1 | 0xE000
  gCedarTrailPlatformTokenSpaceGuid.PcdBootOrderPayload | 0xe3 | 2
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot5Id | 0xe5 | 0x05
  gCedarTrailPlatformTokenSpaceGuid.PcdBootOrderScsi | 0xe7 | 5
  gCedarTrailPlatformTokenSpaceGuid.PcdBootOrderShell | 0xe9 | 0
  gCedarTrailPlatformTokenSpaceGuid.PcdBootOrderDvdCd | 0xeb | 3
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot6Id | 0xed | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot9Id | 0xef | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdBootOrderNetwork | 0xf1 | 6
  gCedarTrailPlatformTokenSpaceGuid.PcdPPMFunctionEnables | 0xf3 | 0x01FF
  gCedarTrailPlatformTokenSpaceGuid.PcdBootOrderFloppy | 0xf5 | 7
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot2Characteristics | 0xf7 | 0x504
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable8GlobalIrq | 0xfb | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot9Characteristics | 0xff | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable1GlobalIrq | 0x103 | 0x09
  gCedarTrailPlatformTokenSpaceGuid.PcdIoApicSettingGlobalInterruptBase | 0x107 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable2GlobalIrq | 0x10b | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable13GlobalIrq | 0x10f | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot1Characteristics | 0x113 | 0x504
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable12GlobalIrq | 0x117 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable10GlobalIrq | 0x11b | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot7Characteristics | 0x11f | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable11GlobalIrq | 0x123 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot10Characteristics | 0x127 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable3GlobalIrq | 0x12b | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot5Characteristics | 0x12f | 0x504
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot6Characteristics | 0x133 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable0GlobalIrq | 0x137 | 0x02
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot4Characteristics | 0x13b | 0x504
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot8Characteristics | 0x13f | 0x0
  gEfiN2x00TokenSpaceGuid.PcdCVDeviceEnables | 0x143 | 0xFFFFFFFF
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable6GlobalIrq | 0x147 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable15GlobalIrq | 0x14b | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot3Characteristics | 0x14f | 0x504
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable14GlobalIrq | 0x153 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdIoApicSettingIoApicAddress | 0x157 | 0xFEC00000
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot12Characteristics | 0x15b | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot14Characteristics | 0x15f | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable7GlobalIrq | 0x163 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable4GlobalIrq | 0x167 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot11Characteristics | 0x16b | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSChassisOemDefined | 0x16f | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot13Characteristics | 0x173 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable5GlobalIrq | 0x177 | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdInterruptOverrideSettingTable9GlobalIrq | 0x17b | 0x0
  gCedarTrailPlatformTokenSpaceGuid.PcdLocalApicAddressOverride | 0x17f | 0x00
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSBiosChar | 0x187 | 0x03037C099880
  gCedarTrailPlatformTokenSpaceGuid.PcdPayloadFile | 0x18f | 16 | { 0xe1, 0xd3, 0x3b, 0xb4, 0xd1, 0x64, 0x44, 0x47, 0x93, 0x94, 0xd0, 0xe1, 0xc4, 0xde, 0x8c, 0x87 }
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemUuid | 0x19f | 16 | {0x23, 0xef, 0xff, 0x13,0x54, 0x86, 0xda, 0x46, 0xa4, 0x7, 0x39, 0xc9, 0x12, 0x2, 0xd3, 0x56}
  gEfiN2x00TokenSpaceGuid.PcdCVPcieRootPortConfiguration | 0x1af | 16 | {0x00, 0x00, 0x01, 0x00, 0x00, 0x01, 0x02, 0x00, 0x00, 0x01, 0x03, 0x00, 0x00, 0x01, 0x04, 0x00}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice1Info | 0x1bf | 18 | {0x00, 0x00, 0x00, 0x00, 0xFF, 0x02, 0x00, 0x00, 0x01, 0x10, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice18Info | 0x1d1 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice7Info  | 0x1e3 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice13Info | 0x1f5 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice46Info | 0x207 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice39Info | 0x219 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice33Info | 0x22b | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice41Info | 0x23d | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice17Info | 0x24f | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice48Info | 0x261 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice16Info | 0x273 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice35Info | 0x285 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice36Info | 0x297 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice50Info | 0x2a9 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice43Info | 0x2bb | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice42Info | 0x2cd | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice8Info  | 0x2df | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice5Info | 0x2f1 | 18 | {0x00, 0x00, 0x00, 0x00, 0xFF, 0x1F, 0x00, 0x00, 0xFF, 0xFF, 0x04, 0x13, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice25Info | 0x303 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice45Info | 0x315 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice32Info | 0x327 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice11Info | 0x339 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice9Info  | 0x34b | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice23Info | 0x35d | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice29Info | 0x36f | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice34Info | 0x381 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice20Info | 0x393 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice47Info | 0x3a5 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice38Info | 0x3b7 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice30Info | 0x3c9 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice3Info | 0x3db | 18 | {0x00, 0x00, 0x00, 0x00, 0xFF, 0x1C, 0x00, 0x00, 0x01, 0x10, 0x02, 0x11, 0x03, 0x12, 0x04, 0x13, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice21Info | 0x3ed | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice28Info | 0x3ff | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice4Info | 0x411 | 18 | {0x00, 0x00, 0x00, 0x00, 0xFF, 0x1D, 0x00, 0x00, 0x04, 0x13, 0x04, 0x13, 0x03, 0x12, 0x01, 0x10, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice37Info | 0x423 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice15Info | 0x435 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice6Info  | 0x447 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice14Info | 0x459 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice27Info | 0x46b | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice2Info | 0x47d | 18 | {0x00, 0x00, 0x00, 0x00, 0xFF, 0x1B, 0x00, 0x00, 0x03, 0x12, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice26Info | 0x48f | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice44Info | 0x4a1 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice19Info | 0x4b3 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice31Info | 0x4c5 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice40Info | 0x4d7 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice10Info | 0x4e9 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice22Info | 0x4fb | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice12Info | 0x50d | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice24Info | 0x51f | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice49Info | 0x531 | 18 | {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF}
  gCedarTrailPlatformTokenSpaceGuid.PcdOemBootOptionName | 0x543 | 50 | "Oem Boot Option"
  gCedarTrailPlatformTokenSpaceGuid.PcdProductTipVersion | 0x575 | 50 | "Gold"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot2Designation | 0x5a7 | 64 | "PCI-Express 1"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort2ExternalConnectorDesignator | 0x5e7 | 64 | "Mouse"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice35Name | 0x627 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort2InternalConnectorDesignator | 0x667 | 64 | "X15 "
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot7Designation | 0x6a7 | 64 | "NONE"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSChassisManufacturer | 0x6e7 | 64 | "Chassis Manufacturer"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice43Name | 0x727 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice21Name | 0x767 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort9ExternalConnectorDesignator | 0x7a7 | 64 | "USB2"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice29Name | 0x7e7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort8InternalConnectorDesignator | 0x827 | 64 | "X20 "
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort13InternalConnectorDesignator | 0x867 | 64 | "J1G1"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice11Name | 0x8a7 | 64 | "PCI Device"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice39Name | 0x8e7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice25Name | 0x927 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice23Name | 0x967 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice42Name | 0x9a7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice41Name | 0x9e7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort3InternalConnectorDesignator | 0xa27 | 64 | "X16 "
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice17Name | 0xa67 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort11InternalConnectorDesignator | 0xaa7 | 64 | "X23 "
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot11Designation | 0xae7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice4Name | 0xb27 | 64 | "USB Device"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice24Name | 0xb67 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot12Designation | 0xba7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort14InternalConnectorDesignator | 0xbe7 | 64 | "J2H2"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort15ExternalConnectorDesignator | 0xc27 | 64 | "SATA1"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice30Name | 0xc67 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice6Name | 0xca7 | 64 | "PCI Express Port 2"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort6InternalConnectorDesignator | 0xce7 | 64 | "X19 "
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSBiosVendor | 0xd27 | 64 | "Intel Corp."
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort8ExternalConnectorDesignator | 0xd67 | 64 | "USB1"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice28Name | 0xda7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort11ExternalConnectorDesignator | 0xde7 | 64 | "USB4"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice47Name | 0xe27 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSerialNumber | 0xe67 | 64 | "Unknown"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot4Designation | 0xea7 | 64 | "PCI-Express 3"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice2Name | 0xee7 | 64 | "Intel High Definition Audio Controller"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort7InternalConnectorDesignator | 0xf27 | 64 | "J4A2"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice49Name | 0xf67 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice38Name | 0xfa7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort9InternalConnectorDesignator | 0xfe7 | 64 | "X21 "
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice9Name | 0x1027 | 64 | "LPC interface"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot10Designation | 0x1067 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice45Name | 0x10a7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot13Designation | 0x10e7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort14ExternalConnectorDesignator | 0x1127 | 64 | "IDE"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot6Designation | 0x1167 | 64 | "NONE"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice16Name | 0x11a7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSChassisSerialNumber | 0x11e7 | 64 | "Chassis Serial Number"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice15Name | 0x1227 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort6ExternalConnectorDesignator | 0x1267 | 64 | "COM 4"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot14Designation | 0x12a7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSChassisVersion | 0x12e7 | 64 | "Chassis Version"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice44Name | 0x1327 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot1Designation | 0x1367 | 64 | "PCI SLOT1"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort12InternalConnectorDesignator | 0x13a7 | 64 | "X28 "
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSBiosReleaseDate | 0x13e7 | 64 | "07/12/2012"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort16ExternalConnectorDesignator | 0x1427 | 64 | "SATA2"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort4ExternalConnectorDesignator | 0x1467 | 64 | "COM 2"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice37Name | 0x14a7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice20Name | 0x14e7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemProductName | 0x1527 | 64 | "Cedar Rock"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice32Name | 0x1567 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSBoardProductName | 0x15a7 | 64 | "REDFORT"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort1ExternalConnectorDesignator | 0x15e7 | 64 | "Keyboard"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice10Name | 0x1627 | 64 | "PCI Device"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice40Name | 0x1667 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort10InternalConnectorDesignator | 0x16a7 | 64 | "X22 "
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort12ExternalConnectorDesignator | 0x16e7 | 64 | "RJ-45 Type"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice7Name | 0x1727 | 64 | "PCI Express Port 3"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice22Name | 0x1767 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice3Name | 0x17a7 | 64 | "PCI Express Root Port"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice33Name | 0x17e7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort3ExternalConnectorDesignator | 0x1827 | 64 | "COM 1"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice26Name | 0x1867 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort15InternalConnectorDesignator | 0x18a7 | 64 | "X29 "
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot3Designation | 0x18e7 | 64 | "PCI-Express 2"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice34Name | 0x1927 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice27Name | 0x1967 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice13Name | 0x19a7 | 64 | "PCI Device"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemVersion | 0x19e7 | 64 | "1.0"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice1Name | 0x1a27 | 64 | "Integrated Graphics"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice8Name | 0x1a67 | 64 | "Intel High Definition Audio Controller"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice31Name | 0x1aa7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort7ExternalConnectorDesignator | 0x1ae7 | 64 | "LPT 1"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort4InternalConnectorDesignator | 0x1b27 | 64 | "X17 "
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort1InternalConnectorDesignator | 0x1b67 | 64 | "X14 "
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort5ExternalConnectorDesignator | 0x1ba7 | 64 | "COM 3"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemManufacturer | 0x1be7 | 64 | "Intel Corp."
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSChassisAssetTag | 0x1c27 | 64 | "Chassis Asset Tag"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSKUNumber | 0x1c67 | 64 | "System SKUNumber"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSBoardManufacturer | 0x1ca7 | 64 | "Intel Corp."
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSBoardSerialNumber | 0x1ce7 | 64 | "3"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice14Name | 0x1d27 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort5InternalConnectorDesignator | 0x1d67 | 64 | "X18 "
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice46Name | 0x1da7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice36Name | 0x1de7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSBiosVersion | 0x1e27 | 64 | "2.3.9.7"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot9Designation | 0x1e67 | 64 | "NONE"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort13ExternalConnectorDesignator | 0x1ea7 | 64 | "Floppy"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice48Name | 0x1ee7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice18Name | 0x1f27 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice50Name | 0x1f67 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice5Name | 0x1fa7 | 64 | "LPC Device"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort10ExternalConnectorDesignator | 0x1fe7 | 64 | "USB3"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot5Designation | 0x2027 | 64 | "Mini PCI-E"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSBoardVersion | 0x2067 | 64 | "FAB-2"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemFamily | 0x20a7 | 64 | "N2x00"
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice12Name | 0x20e7 | 64 | "PCI Device"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSSystemSlot8Designation | 0x2127 | 64 | "NONE"
  gCedarTrailPlatformTokenSpaceGuid.PcdSMBIOSPort16InternalConnectorDesignator | 0x2167 | 64 | "X30 "
  gCedarTrailPlatformTokenSpaceGuid.PcdPciDevice19Name | 0x21a7 | 64 | "None"
  gCedarTrailPlatformTokenSpaceGuid.PcdOemBootOptionPath | 0x21e7 | 100 | "\efi\oem\OemBootOption.efi"
  gCedarTrailPlatformTokenSpaceGuid.PcdBDSBannerString | 0x224b | 100 | "Intel(R) Boot Loader Development Kit"
  gEfiCpuTokenSpaceGuid.PcdCpuVtLtFlag | 0x22af | TRUE
  gEfiCpuTokenSpaceGuid.PcdCpuFerrSignalBreakFlag | 0x22b0 | TRUE
  gEfiCpuTokenSpaceGuid.PcdCpuMachineCheckFlag | 0x22b1 | TRUE
  gEfiCpuTokenSpaceGuid.PcdCpuMaxCpuIDValueLimitFlag | 0x22b2 | FALSE
  gCedarTrailPlatformTokenSpaceGuid.PcdEnableFastBoot  |0x22b3|  FALSE

  #GPIO PCDs below, please refer EDS doc to understand the naming conventions.
  gEfiNm10TokenSpaceGuid.PcdNm10IohGpioUseSel  | 0x22b5 | 0x1F42F7C3
  gEfiNm10TokenSpaceGuid.PcdNm10IohGpioIoSel   | 0x22b9 | 0xF0EABF03
  gEfiNm10TokenSpaceGuid.PcdNm10GpioGpLvl      | 0x22bD | 0xFFD57E03
  gEfiNm10TokenSpaceGuid.PcdNm10GpioGpioBlink  | 0x22c1 | 0x00040000
  gEfiNm10TokenSpaceGuid.PcdNm10GpioGpioGpiInv | 0x22c5 | 0x000026C2
  gEfiNm10TokenSpaceGuid.PcdNm10IohGpioUseSel2 | 0x22c9 | 0x000000D6
  gEfiNm10TokenSpaceGuid.PcdNm10IohGpioIoSel2  | 0x22cD | 0x000000E6
  gEfiNm10TokenSpaceGuid.PcdNm10GpioGpLvl2     | 0x22d1 | 0x00020037
 
  gCedarTrailPlatformTokenSpaceGuid.PcdCopyRightBannerString | 0x22d5 | 100 | "Copyright (C) 1999-2012 Intel Corporation. All rights reserved."
 
  gEfiMdeModulePkgTokenSpaceGuid.PcdFirmwareVendor| 0x2339 | 16 | "EDK II"
  gEfiMdeModulePkgTokenSpaceGuid.PcdFirmwareRevision | 0x2349 | 0x00010000

  gEfiNm10TokenSpaceGuid.PcdEhciRecoveryEnabled | 0x2359 | FALSE
  gEfiNm10TokenSpaceGuid.PcdPeiUsbControllerMemoryBaseAddress | 0x235A | 0xA0010000
  gEfiSioTokenSpaceGuid.PcdSioEnablePs2Keyboard | 0x235E | TRUE
  gEfiSioTokenSpaceGuid.PcdSioEnablePs2Mouse | 0x235F | TRUE
  
  gEfiN2x00TokenSpaceGuid.PcdCVSmbaIoBaseAddress | 0x2360 |0xEFA0
  gEfiN2x00TokenSpaceGuid.PcdCVApmIoBaseAddress | 0x2362 |0x1180
  gEfiN2x00TokenSpaceGuid.PcdCVOspmIoBaseAddress | 0x2364 |0x1100
  gEfiN2x00TokenSpaceGuid.PcdCVPmbaIoBaseAddress | 0x2366 |0x0400
  gEfiN2x00TokenSpaceGuid.PcdCVGpe0blkIoBaseAddress | 0x2368 |0x0428
  gEfiN2x00TokenSpaceGuid.PcdCVPsmiIoBaseAddress | 0x236A |0x1140
  gCedarTrailPlatformTokenSpaceGuid.PcdBootPState | 0x236C | 1
 
  gEfiTianoModulePkgTokenSpaceGuid.PcdSataSpinUpDelayInSecForRecoveryPath | 0x236D | 15
  
  gPcAtChipsetPkgTokenSpaceGuid.Pcd8259LegacyModeEdgeLevel | 0x236F |0x0000
  gPcAtChipsetPkgTokenSpaceGuid.Pcd8259LegacyModeMask | 0x2371 |0xFFFF

  gCedarTrailPlatformTokenSpaceGuid.PcdGopBltEnable | 0x2373 | TRUE
  gCedarTrailPlatformTokenSpaceGuid.PcdBootWEC7 | 0x2374 | FALSE

  gCedarTrailPlatformTokenSpaceGuid.GraphicsResolution |0x2375| 0x00
  gEfiSioTokenSpaceGuid.PcdSioEnableSerialPort | 0x2376 | TRUE

###################################################################################################
#
# Components Section - list of the modules and components that will be processed by compilation
#                      tools and the EDK II tools to generate PE32/PE32+/Coff image files.
#
# Note: The EDK II DSC file is not used to specify how compiled binary images get placed
#       into firmware volume images. This section is just a list of modules to compile from
#       source into UEFI-compliant binaries.
#       It is the FDF file that contains information on combining binary files into firmware
#       volume images, whose concept is beyond UEFI and is described in PI specification.
#       Binary modules do not need to be listed in this section, as they should be
#       specified in the FDF file. For example: Shell binary (Shell_Full.efi), FAT binary (Fat.efi),
#       Logo (Logo.bmp), and etc.
#       There may also be modules listed in this section that are not required in the FDF file,
#       When a module listed here is excluded from FDF file, then UEFI-compliant binary will be
#       generated for it, but the binary will not be put into any firmware volume.
#
###################################################################################################

[Components.IA32]
  #
  # SEC Core
  #
  IA32FamilyCpuPkg/SecCore/SecCore.inf

  #
  # PEI Core
  #
  MdeModulePkg/Core/Pei/PeiMain.inf  {
    <PcdsFixedAtBuild>
      gEfiMdePkgTokenSpaceGuid.PcdDebugPropertyMask|0x27
  }

  #
  # PEIM
  #
  UefiCpuPkg/CpuIoPei/CpuIoPei.inf {
    <LibraryClasses>
      IoLib|MdePkg/Library/BaseIoLibIntrinsic/BaseIoLibIntrinsic.inf
  }
  MdeModulePkg/Universal/PCD/Pei/Pcd.inf {
    <LibraryClasses>
      PcdLib|MdePkg/Library/BasePcdLibNull/BasePcdLibNull.inf
  }

  IntelFrameworkModulePkg/Universal/StatusCode/Pei/StatusCodePei.inf

  $(PLATFORM_PACKAGE)/CpuPei/CpuPeim.inf
  $(PLATFORM_PACKAGE)/PlatformPei/PlatformPei.inf
  Nm10Pkg/Smbus/Pei/IchSmbusArpDisabled.inf
  $(PLATFORM_PACKAGE)/PcatSingleSegmentPciCfgPei/PcatSingleSegmentPciCfgPei.inf
  CedarViewPkg/CvInit/Pei/CvInitPeim.inf
  Nm10Pkg/IchInit/Pei/IchInitPeim.inf
  Nm10Pkg/Spi/Pei/IchSpiPeim.inf

  $(PLATFORM_PACKAGE)/CK505/Pei/PeiCK505.inf
  $(PLATFORM_PACKAGE)/FvInfoPei/FvInfoPei.inf
  CedarViewPkg/MemoryInit/Pei/MemoryInit.inf

  MdeModulePkg/Universal/Variable/Pei/VariablePei.inf
  TianoModulePkg/Universal/CapsulePei/CapsulePei.inf

  MdeModulePkg/Core/DxeIplPeim/DxeIpl.inf {
    <LibraryClasses>
      NULL|IntelFrameworkModulePkg/Library/LzmaCustomDecompressLib/LzmaCustomDecompressLib.inf
  }

  #
  # S3
  #
  TianoModulePkg/Universal/Acpi/S3Resume2Pei/S3Resume2Pei.inf

  Nm10Pkg/UsbPei/UsbPei.inf
  TianoModulePkg/Bus/Pci/EhciPei/EhciPei.inf
  TianoModulePkg/Bus/Usb/UsbBusPei/UsbBusPei.inf
  TianoModulePkg/Bus/Usb/UsbBotPei/UsbBotPei.inf
  TianoModulePkg/Universal/Disk/FileSystem/FatPei/FatPei.inf
  TianoModulePkg/Universal/Disk/FileSystem/CDExpressPei/CdExpressPei.inf
  TianoModulePkg/Bus/Pci/IdeBusPei/IdeBusPei.inf
  CedarViewPkg/SmmAccess/Pei/SmmAccess.inf
  $(PLATFORM_PACKAGE)/Override/AcpiVariableHobOnSmramReserveHobThunk/AcpiVariableHobOnSmramReserveHobThunk.inf

[Components.IA32]
  #
  # DXE Core
  #
  MdeModulePkg/Core/Dxe/DxeMain.inf {
    <LibraryClasses>
      PcdLib|MdePkg/Library/BasePcdLibNull/BasePcdLibNull.inf
      NULL|IntelFrameworkModulePkg/Library/LzmaCustomDecompressLib/LzmaCustomDecompressLib.inf
      NULL|MdeModulePkg/Library/DxeCrc32GuidedSectionExtractLib/DxeCrc32GuidedSectionExtractLib.inf
    <PcdsFixedAtBuild>
      gEfiMdePkgTokenSpaceGuid.PcdDebugPropertyMask|0x27
  }

  #
  # Components that produce the architectural protocols
  #
  MdeModulePkg/Universal/SecurityStubDxe/SecurityStubDxe.inf
  IA32FamilyCpuPkg/CpuArchDxe/CpuArchDxe.inf
  $(PLATFORM_PACKAGE)/Override/CpuMpDxe/CpuMpDxe.inf
  $(PLATFORM_PACKAGE)/Metronome/Metronome.inf
  $(PLATFORM_PACKAGE)/BdsDxe/BdsDxe.inf
  MdeModulePkg/Universal/WatchdogTimerDxe/WatchdogTimer.inf
  MdeModulePkg/Core/RuntimeDxe/RuntimeDxe.inf
  MdeModulePkg/Universal/FaultTolerantWriteDxe/FaultTolerantWriteDxe.inf
  MdeModulePkg/Universal/Variable/RuntimeDxe/VariableRuntimeDxe.inf
  MdeModulePkg/Universal/CapsuleRuntimeDxe/CapsuleRuntimeDxe.inf
  MdeModulePkg/Universal/MonotonicCounterRuntimeDxe/MonotonicCounterRuntimeDxe.inf
  PcAtChipsetPkg/PcatRealTimeClockRuntimeDxe/PcatRealTimeClockRuntimeDxe.inf

  #
  # Following are the DXE drivers (alphabetical order)
  #
  $(PLATFORM_PACKAGE)/Binary/CpuMicrocode/CpuMicrocode.inf
  MdeModulePkg/Universal/DevicePathDxe/DevicePathDxe.inf
  MdeModulePkg/Universal/PCD/Dxe/Pcd.inf {
    <LibraryClasses>
      PcdLib|MdePkg/Library/BasePcdLibNull/BasePcdLibNull.inf
  }

  $(PLATFORM_PACKAGE)/FvbRuntimeDxe/FvbRuntimeDxe.inf

  IntelFrameworkModulePkg/Universal/CpuIoDxe/CpuIoDxe.inf
  UefiCpuPkg/CpuIo2Dxe/CpuIo2Dxe.inf {
    <LibraryClasses>
      IoLib|MdePkg/Library/BaseIoLibIntrinsic/BaseIoLibIntrinsic.inf
  }
  $(PLATFORM_PACKAGE)/SetupDxe/SetupDxe.inf {       
    <LibraryClasses>       
      PciLib|MdePkg/Library/BasePciLibPciExpress/BasePciLibPciExpress.inf       
  }
  IntelFrameworkModulePkg/Universal/DataHubDxe/DataHubDxe.inf
  IntelFrameworkModulePkg/Universal/DataHubStdErrDxe/DataHubStdErrDxe.inf
  IntelFrameworkModulePkg/Universal/SectionExtractionDxe/SectionExtractionDxe.inf
  MdeModulePkg/Universal/ReportStatusCodeRouter/RuntimeDxe/ReportStatusCodeRouterRuntimeDxe.inf
  MdeModulePkg/Universal/StatusCodeHandler/RuntimeDxe/StatusCodeHandlerRuntimeDxe.inf
  MdeModulePkg/Universal/ReportStatusCodeRouter/Smm/ReportStatusCodeRouterSmm.inf
  MdeModulePkg/Universal/StatusCodeHandler/Smm/StatusCodeHandlerSmm.inf
  MdeModulePkg/Universal/MemoryTest/NullMemoryTestDxe/NullMemoryTestDxe.inf
  $(PLATFORM_PACKAGE)/PlatformDxe/PlatformDxe.inf

  #
  # ACPI
  #
  TianoModulePkg/Universal/Acpi/S3SaveStateDxe/S3SaveStateDxe.inf
  TianoModulePkg/Universal/Acpi/BootScriptSaveDxe/BootScriptSaveDxe.inf
  TianoModulePkg/Universal/Acpi/BootScriptExecutorDxe/BootScriptExecutorDxe.inf
  $(PLATFORM_PACKAGE)/Override/AcpiS3SaveDxe/AcpiS3SaveDxe.inf
  $(PLATFORM_PACKAGE)/Override/AcpiSupportDxe/AcpiSupportDxe.inf
  $(PLATFORM_PACKAGE)/AcpiTables/AcpiTables.inf
  $(PLATFORM_PACKAGE)/AcpiPlatform/AcpiPlatform.inf
  $(PLATFORM_PACKAGE)/PowerManagement/AcpiTables/PowerManagementAcpiTables.inf

  #
  # SMM
  #
  MdeModulePkg/Core/PiSmmCore/PiSmmIpl.inf
  MdeModulePkg/Core/PiSmmCore/PiSmmCore.inf
  IA32FamilyCpuPkg/PiSmmCpuDxeSmm/PiSmmCpuDxeSmm.inf
  UefiCpuPkg/CpuIo2Smm/CpuIo2Smm.inf

  CedarViewPkg/SmmAccess/Dxe/SmmAccess.inf
  $(PLATFORM_PACKAGE)/PowerManagement/Smm/PowerManagement.inf
  $(PLATFORM_PACKAGE)/PpmPolicy/PpmPolicy.inf
  $(PLATFORM_PACKAGE)/SmramSaveInfoHandlerSmm/SmramSaveInfoHandlerSmm.inf
  $(PLATFORM_PACKAGE)/PlatformSmm/PlatformSmm.inf

  #
  # SMBIOS
  #
  MdeModulePkg/Universal/SmbiosDxe/SmbiosDxe.inf
  $(PLATFORM_PACKAGE)/SmbiosMiscDxe/SmbiosMiscDxe.inf
  CedarViewPkg/SmBiosMemory/Dxe/SmBiosMemory.inf
  $(PLATFORM_PACKAGE)/SaveMemoryConfig/SaveMemoryConfig.inf

  #
  # PCI
  #
  $(PLATFORM_PACKAGE)/PciPlatform/PciPlatform.inf
  MdeModulePkg/Bus/Pci/PciBusDxe/PciBusDxe.inf

  #
  # USB
  #
  MdeModulePkg/Bus/Pci/EhciDxe/EhciDxe.inf
  MdeModulePkg/Bus/Pci/UhciDxe/UhciDxe.inf
  MdeModulePkg/Bus/Usb/UsbBusDxe/UsbBusDxe.inf
  MdeModulePkg/Bus/Usb/UsbKbDxe/UsbKbDxe.inf
  MdeModulePkg/Bus/Usb/UsbMouseDxe/UsbMouseDxe.inf
  MdeModulePkg/Bus/Usb/UsbMassStorageDxe/UsbMassStorageDxe.inf

  #
  # IDE/SCSI
  #
  MdeModulePkg/Universal/Disk/DiskIoDxe/DiskIoDxe.inf
  MdeModulePkg/Universal/Disk/PartitionDxe/PartitionDxe.inf
  Nm10Pkg/AhciDxe/AhciDxe.inf
  IntelFrameworkModulePkg/Bus/Pci/IdeBusDxe/IdeBusDxe.inf

  #
  # ISA
  #
  Npce791Pkg/Npce791Dxe/Npce791Dxe.inf
  IntelFrameworkModulePkg/Bus/Isa/IsaBusDxe/IsaBusDxe.inf
  IntelFrameworkModulePkg/Bus/Isa/IsaSerialDxe/IsaSerialDxe.inf {
    <LibraryClasses>
      PcdLib|MdePkg/Library/DxePcdLib/DxePcdLib.inf
  }
  $(PLATFORM_PACKAGE)/Override/Ps2KeyboardDxe/Ps2keyboardDxe.inf
  $(PLATFORM_PACKAGE)/Override/Ps2MouseDxe/Ps2MouseDxe.inf

  #
  # Console
  #
  MdeModulePkg/Universal/Console/ConPlatformDxe/ConPlatformDxe.inf
  MdeModulePkg/Universal/Console/ConSplitterDxe/ConSplitterDxe.inf {
    <LibraryClasses>
      PcdLib|MdePkg/Library/DxePcdLib/DxePcdLib.inf
  }
  $(PLATFORM_PACKAGE)/Override/GraphicsConsoleDxe/GraphicsConsoleDxe.inf {
    <LibraryClasses>
      PcdLib|MdePkg/Library/DxePcdLib/DxePcdLib.inf
  }
  MdeModulePkg/Universal/Console/TerminalDxe/TerminalDxe.inf
  MdeModulePkg/Universal/HiiDatabaseDxe/HiiDatabaseDxe.inf
  MdeModulePkg/Universal/SetupBrowserDxe/SetupBrowserDxe.inf
  MdeModulePkg/Universal/Disk/UnicodeCollation/EnglishDxe/EnglishDxe.inf

  #
  # Reference Code
  #
  Nm10Pkg/SmartTimer/Dxe/SmartTimer.inf
  Nm10Pkg/SmmControl/Dxe/SmmControl.inf
  Nm10Pkg/Smbus/Dxe/IchSmbus.inf
  Nm10Pkg/Reset/RuntimeDxe/IntelIchReset.inf
  Nm10Pkg/IchInit/Dxe/IchInit.inf
  Nm10Pkg/IoTrap/Smm/IoTrap.inf
  Nm10Pkg/IchSmiDispatcher/Smm/IchTptSmmDispatcher.inf
  Nm10Pkg/Spi/RuntimeDxe/IchSpi.inf

  Nm10Pkg/SataController/Dxe/SataController.inf{
    <LibraryClasses>
    PcdLib|MdePkg/Library/DxePcdLib/DxePcdLib.inf
  }

  CedarViewPkg/CvInit/Dxe/CvInit.inf
  CedarViewPkg/PciHostBridge/Dxe/PciHostBridge.inf
  CedarViewPkg/PciExpress/Dxe/PciExpress.inf

  #
  # Igd
  #

  #
  # Shell and Applications
  #

  #
  # Legacy Modules
  #
  PcAtChipsetPkg/8259InterruptControllerDxe/8259.inf

  #
  # Misc Modules
  #
  $(PLATFORM_PACKAGE)/FlashProtocol/FlashProtocol.inf

[BuildOptions.Common.EDK]
  DEBUG_*_IA32_CC_FLAGS   = /D EFI_SPECIFICATION_VERSION=0x00020000  /D PI_SPECIFICATION_VERSION=0x00000009  /D TIANO_RELEASE_VERSION=0x00080006 /D SUPPORT_DEPRECATED_PCI_CFG_PPI /D CSM_SMMENTRY_PORT8DATA8 /D PLATFORM_PCIEXPRESS_LENGTH=0x$(PLATFORM_PCIEXPRESS_LEN) /D PCIEX_LENGTH_BIT_SETTING=0b$(PLATFORM_PCIEX_LENGTH_BIT_SETTING) /D EDKII_GLUE_PciExpressBaseAddress=0x$(PLATFORM_PCIEXPRESS_BASE) /D MAX_VARIABLE_SIZE=0x2000 /D EFI_FIRMWARE_VENDOR="L/"INTEL/"" /D EFI_BUILD_VERSION="L/"EDKII/"" /DEFI_PEI_REPORT_STATUS_CODE_ON /DEFI_DEBUG
  RELEASE_*_IA32_CC_FLAGS = /D EFI_SPECIFICATION_VERSION=0x00020000  /D PI_SPECIFICATION_VERSION=0x00000009  /D TIANO_RELEASE_VERSION=0x00080006 /D SUPPORT_DEPRECATED_PCI_CFG_PPI /D CSM_SMMENTRY_PORT8DATA8 /D PLATFORM_PCIEXPRESS_LENGTH=0x$(PLATFORM_PCIEXPRESS_LEN) /D PCIEX_LENGTH_BIT_SETTING=0b$(PLATFORM_PCIEX_LENGTH_BIT_SETTING) /D EDKII_GLUE_PciExpressBaseAddress=0x$(PLATFORM_PCIEXPRESS_BASE) /D MAX_VARIABLE_SIZE=0x2000 /D EFI_FIRMWARE_VENDOR="L/"INTEL/"" /D EFI_BUILD_VERSION="L/"EDKII/"" /DEFI_PEI_REPORT_STATUS_CODE_ON

