/*++
  This file contains 'Framework Code' and is licensed as such   
  under the terms of your license agreement with Intel or your  
  vendor.  This file may not be modified, except as allowed by  
  additional terms of your license agreement.                   
--*/
/*++

Copyright (c) 2006 - 2010, Intel Corporation. All rights reserved.<BR>
This software and associated documentation (if any) is furnished
under a license and may only be used or copied in accordance
with the terms of the license. Except as permitted by such
license, no part of this software or documentation may be
reproduced, stored in a retrieval system, or transmitted in any
form or by any means without the express written consent of
Intel Corporation.

Module Name:

  PlatformData.c

Abstract:

  Defined the platform specific device path which will be used by
  platform Bbd to perform the platform policy connect.

--*/



#include "BdsPlatform.h"

//
// Predefined platform default time out value
//
UINT16  gPlatformBootTimeOutDefault = 10;

//
// Predefined platform root bridge
//
PLATFORM_ROOT_BRIDGE_DEVICE_PATH gPlatformRootBridge0 = {
  gPciRootBridge,
  gEndEntire
};

EFI_DEVICE_PATH_PROTOCOL* gPlatformRootBridges [] = {
  (EFI_DEVICE_PATH_PROTOCOL*)&gPlatformRootBridge0,
  NULL
};

//
// Platform specific keyboard device path
//
PLATFORM_KEYBOARD_DEVICE_PATH gPs2KeyboardDevicePath = {
  gPciRootBridge,
  { 
    HARDWARE_DEVICE_PATH,
    HW_PCI_DP,
    (UINT8)(sizeof(PCI_DEVICE_PATH)),
    (UINT8)((sizeof(PCI_DEVICE_PATH)) >> 8),
    0,
    0x1f
  },
  { 
    ACPI_DEVICE_PATH,
    ACPI_DP,
    (UINT8)(sizeof(ACPI_HID_DEVICE_PATH)),
    (UINT8)((sizeof(ACPI_HID_DEVICE_PATH)) >> 8),
    EISA_PNP_ID(0x0303),
    0
  },
  gEndEntire
};


USB_CLASS_FORMAT_DEVICE_PATH gUsbClassKeyboardDevicePath = {
  {
    {
      MESSAGING_DEVICE_PATH,
      MSG_USB_CLASS_DP,
      (UINT8) (sizeof (USB_CLASS_DEVICE_PATH)),
      (UINT8) ((sizeof (USB_CLASS_DEVICE_PATH)) >> 8)
    },
    0xffff,           // VendorId 
    0xffff,           // ProductId 
    CLASS_HID,        // DeviceClass 
    SUBCLASS_BOOT,    // DeviceSubClass
    PROTOCOL_KEYBOARD // DeviceProtocol
  },

  { 
    END_DEVICE_PATH_TYPE, 
    END_ENTIRE_DEVICE_PATH_SUBTYPE, 
    END_DEVICE_PATH_LENGTH, 
    0
  }
};


//
// Platform specific on chip Agp device path
//
PLATFORM_ONBOARD_VGA_DEVICE_PATH gOnChipAgpDevicePath = {
  gPciRootBridge,
  {
    HARDWARE_DEVICE_PATH,
    HW_PCI_DP,
    (UINT8)(sizeof(PCI_DEVICE_PATH)),
    (UINT8)((sizeof(PCI_DEVICE_PATH)) >> 8),
    0,
    0x2
  },
  gEndEntire
};

//
// Platform specific plug in Agp device path
//
PLATFORM_AGP_DEVICE_PATH gPlugInAgpDevicePath = {
  gPciRootBridge,
  {
    HARDWARE_DEVICE_PATH,
    HW_PCI_DP,
    (UINT8)(sizeof(PCI_DEVICE_PATH)),
    (UINT8)((sizeof(PCI_DEVICE_PATH)) >> 8),
    0,
    0x1
  },
  {
    HARDWARE_DEVICE_PATH,
    HW_PCI_DP,
    (UINT8)(sizeof(PCI_DEVICE_PATH)),
    (UINT8)((sizeof(PCI_DEVICE_PATH)) >> 8),
    0,
    0
  },
  gEndEntire
};

//
// Platform specific serial device path
//
PLATFORM_ISA_SERIAL_DEVICE_PATH gSerialDevicePath = {
  gPciRootBridge,
  { 
    HARDWARE_DEVICE_PATH,
    HW_PCI_DP,
    (UINT8)(sizeof(PCI_DEVICE_PATH)),
    (UINT8)((sizeof(PCI_DEVICE_PATH)) >> 8),
    0x0,
    0x1f
  },
  {
    ACPI_DEVICE_PATH,
    ACPI_DP,
    (UINT8)(sizeof(ACPI_HID_DEVICE_PATH)),
    (UINT8)((sizeof(ACPI_HID_DEVICE_PATH)) >> 8),
    EISA_PNP_ID(0x0501),
    0
  },
  { 
    MESSAGING_DEVICE_PATH,
    MSG_UART_DP,
    (UINT8)(sizeof(UART_DEVICE_PATH)),
    (UINT8)((sizeof(UART_DEVICE_PATH)) >> 8),
    0,
    115200,
    8,
    1,
    1
  },
  { 
    MESSAGING_DEVICE_PATH,
    MSG_VENDOR_DP,
    (UINT8)(sizeof(VENDOR_DEVICE_PATH)),
    (UINT8)((sizeof(VENDOR_DEVICE_PATH)) >> 8),
    DEVICE_PATH_MESSAGING_PC_ANSI
  },
  gEndEntire
};

//
// Platform specific serial over lan device path
//
PLATFORM_ISA_SERIAL_OVER_LAN_DEVICE_PATH gSerialOverLANDevicePath = {
  gPciRootBridge,
  { 
    HARDWARE_DEVICE_PATH,
    HW_PCI_DP,
    (UINT8)(sizeof(PCI_DEVICE_PATH)),
    (UINT8)((sizeof(PCI_DEVICE_PATH)) >> 8),
    0x0,
    0x1c
  },
  {
    HARDWARE_DEVICE_PATH,
    HW_PCI_DP,
    (UINT8)(sizeof(PCI_DEVICE_PATH)),
    (UINT8)((sizeof(PCI_DEVICE_PATH)) >> 8),
    0x3,
    0x0
  },
  { 
    MESSAGING_DEVICE_PATH,
    MSG_UART_DP,
    (UINT8)(sizeof(UART_DEVICE_PATH)),
    (UINT8)((sizeof(UART_DEVICE_PATH)) >> 8),
    0,
    115200,
    8,
    1,
    1
  },
  { 
    MESSAGING_DEVICE_PATH,
    MSG_VENDOR_DP,
    (UINT8)(sizeof(VENDOR_DEVICE_PATH)),
    (UINT8)((sizeof(VENDOR_DEVICE_PATH)) >> 8),
    DEVICE_PATH_MESSAGING_PC_ANSI
  },
  gEndEntire
};

//
// Predefined platform default console device path
//
BDS_CONSOLE_CONNECT_ENTRY gPlatformConsole [] = {
  {(EFI_DEVICE_PATH_PROTOCOL*)&gSerialDevicePath, (CONSOLE_OUT | CONSOLE_IN)},
  {(EFI_DEVICE_PATH_PROTOCOL*)&gPs2KeyboardDevicePath, CONSOLE_IN},
  {(EFI_DEVICE_PATH_PROTOCOL*)&gUsbClassKeyboardDevicePath, CONSOLE_IN},
  {NULL, 0}
};

//
// All the possible platform Agp device path
//
EFI_DEVICE_PATH_PROTOCOL* gPlatformAllPossibleAgpConsole [] = {
  (EFI_DEVICE_PATH_PROTOCOL*)&gOnChipAgpDevicePath,
  (EFI_DEVICE_PATH_PROTOCOL*)&gPlugInAgpDevicePath,
  NULL
};

//
// Legacy hard disk boot option 
//
LEGACY_HD_DEVICE_PATH gLegacyHd = {
  {
    BBS_DEVICE_PATH,
    BBS_BBS_DP,
    (UINT8)(sizeof(BBS_BBS_DEVICE_PATH)),
    (UINT8)((sizeof(BBS_BBS_DEVICE_PATH)) >> 8),
    BBS_TYPE_HARDDRIVE,
    0,
    0
  },
  gEndEntire
};

//
// Legacy cdrom boot option
//
LEGACY_HD_DEVICE_PATH gLegacyCdrom = {
  {
    BBS_DEVICE_PATH,
    BBS_BBS_DP,
    (UINT8)(sizeof(BBS_BBS_DEVICE_PATH)),
    (UINT8)((sizeof(BBS_BBS_DEVICE_PATH)) >> 8),
    BBS_TYPE_CDROM,
    0,
    0
  },
  gEndEntire
};

//
// Predefined platform specific perdict boot option
//
EFI_DEVICE_PATH_PROTOCOL* gPlatformBootOption [] = {
  (EFI_DEVICE_PATH_PROTOCOL*)&gLegacyHd,
  (EFI_DEVICE_PATH_PROTOCOL*)&gLegacyCdrom,
  NULL
};

//
// Predefined platform specific driver option
//
EFI_DEVICE_PATH_PROTOCOL* gPlatformDriverOption [] = {
  NULL
};

//
// Predefined platform connect sequence
//
EFI_DEVICE_PATH_PROTOCOL* gPlatformConnectSequence [] = {
  NULL
};

//
// Platform specific USB controller device path
//
PLATFORM_USB_DEVICE_PATH gUsbDevicePath0 = {
  gPciRootBridge,
  { 
    HARDWARE_DEVICE_PATH,
    HW_PCI_DP,
    (UINT8)(sizeof(PCI_DEVICE_PATH)),
    (UINT8)((sizeof(PCI_DEVICE_PATH)) >> 8),
    0x0,
    0x1D
  },
  gEndEntire
};

//
// Platform specific USB controller device path
//
PLATFORM_USB_DEVICE_PATH gUsbDevicePath1 = {
  gPciRootBridge,
  { 
    HARDWARE_DEVICE_PATH,
    HW_PCI_DP,
    (UINT8)(sizeof(PCI_DEVICE_PATH)),
    (UINT8)((sizeof(PCI_DEVICE_PATH)) >> 8),
    0x1,
    0x1D
  },
  gEndEntire
};

//
// Platform specific USB controller device path
//
PLATFORM_USB_DEVICE_PATH gUsbDevicePath2 = {
  gPciRootBridge,
  { 
    HARDWARE_DEVICE_PATH,
    HW_PCI_DP,
    (UINT8)(sizeof(PCI_DEVICE_PATH)),
    (UINT8)((sizeof(PCI_DEVICE_PATH)) >> 8),
    0x2,
    0x1D
  },
  gEndEntire
};

//
// Platform specific USB controller device path
//
PLATFORM_USB_DEVICE_PATH gUsbDevicePath3 = {
  gPciRootBridge,
  { 
    HARDWARE_DEVICE_PATH,
    HW_PCI_DP,
    (UINT8)(sizeof(PCI_DEVICE_PATH)),
    (UINT8)((sizeof(PCI_DEVICE_PATH)) >> 8),
    0x3,
    0x1D
  },
  gEndEntire
};

//
// Predefined platform device path for user authtication
//
EFI_DEVICE_PATH_PROTOCOL* gUserAuthenticationDevice[] = {
  //
  // Predefined device path for secure card (USB disk).
  //
  (EFI_DEVICE_PATH_PROTOCOL*)&gUsbDevicePath0,
  (EFI_DEVICE_PATH_PROTOCOL*)&gUsbDevicePath1,
  (EFI_DEVICE_PATH_PROTOCOL*)&gUsbDevicePath2,
  (EFI_DEVICE_PATH_PROTOCOL*)&gUsbDevicePath3,
  NULL
};


