//
// This file contains 'Framework Code' and is licensed as such 
// under the terms of your license agreement with Intel or your
// vendor.  This file may not be modified, except as allowed by
// additional terms of your license agreement.                 
//
/** @file
  Header file of Serial Port hardware definition.

  Copyright (c) 2010-2012 Intel Corporation.
  All rights reserved.  This software and associated documentation
  (if any) is furnished under a license and may only be used or
  copied in accordance with the terms of the license.  Except as
  permitted by such license, no part of this software or
  documentation may be reproduced, stored in a retrieval system, or
  transmitted in any form or by any means without the express written
  consent of Intel Corporation.

  Module Name:  SerialPortLib.h

**/

#ifndef _SERIAL_PORT_LIB_H_
#define _SERIAL_PORT_LIB_H_

//
// Port address
//
#define SIO_CONFIG_PORT 0x04E
#define SIO_INDEX_PORT  0x04E
#define SIO_DATA_PORT   (SIO_INDEX_PORT + 1)


//
// Global configuration register
//
#define R_SIO_CONFIG_CONTROL  0x02

#define R_SIO_LOGICAL_DEVICE  0x07 // Used to select current device
#define   V_SIO_FLOPPY          0x0
#define   V_SIO_PARA            0x1
#define   V_SIO_SERIAL_PORT_2   0x2
#define   V_SIO_SERIAL_PORT_1   0x3
#define   V_SIO_SERIAL_PORT_1_N 0x4
#define   V_SIO_MOUSE           0x5
#define   V_SIO_KYBD            0x6
#define   V_SIO_POWER_CONTROL   0x4
#define   V_SIO_GPIO            0x7
#define   V_SIO_FAN             0x9

#define R_SIO_DEVICE_ID       0x20
#define R_SIO_DEVICE_REV      0x21

#define R_SIO_SMSC_TEST8      0x28
#define R_SIO_SMSC_TEST7      0x29
#define R_SIO_SMSC_TEST6      0x2A
#define R_SIO_SMSC_TEST4      0x2B
#define R_SIO_SMSC_TEST5      0x2C
#define R_SIO_SMSC_TEST1      0x2D
#define R_SIO_SMSC_TEST2      0x2E
#define R_SIO_SMSC_TEST3      0x2F

#define R_SIO_POWER_CONTROL   0x22 // Bit 1, 2, 6 and 7 are reserved
#define   V_SIO_FLOPPY_POWER    0x01
#define   V_SIO_PARA_POWER      0x08
#define   V_SIO_SERIAL_PORT_1_POWER       0x10
#define   V_SIO_SERIAL_PORT_2_POWER       0x20

#define R_SIO_ACTIVATE                  0x30
#define R_SIO_BASE_ADDRESS_HIGH         0x60
#define R_SIO_BASE_ADDRESS_LOW          0x61
#define R_SIO_BASE_ADDRESS_HIGH2        0x62
#define R_SIO_BASE_ADDRESS_LOW2         0x63
#define R_SIO_PRIMARY_INTERRUPT_SELECT  0x70
#define R_SIO_SECOND_INTERRUPT_SELECT   0x72
#define R_SIO_DMA_CHANNEL_SELECT        0x74


//
// Register for serial port, each port has same layout, so they can
// share these definitions.
//
#define R_SIO_SERIAL_MODE                  0xF0 // Serial Port Mode Register
#define R_SIO_SERIAL_IR_OPTION             0xF1 // IR Options Register
#define R_SIO_SERIAL_IR_HALFDULEX_TIMEOUT  0xF2 // IR Half Duplex Timeout


//
// ---------------------------------------------
// UART Register Offset and Bitmask of Value
// ---------------------------------------------
//
#define R_UART_BAUD_LOW       0
#define R_UART_BAUD_HIGH      1
#define R_UART_IER            1
#define R_UART_LCR_SHADOW     1
#define R_UART_FCR_SHADOW     2
#define R_UART_IR_CONTROL     2
#define R_UART_FCR            2
#define   B_UARY_FCR_TRFIFIE  BIT0
#define   B_UARY_FCR_RESETRF  BIT1
#define   B_UARY_FCR_RESETTF  BIT2
#define R_UART_EIR            2
#define R_UART_BSR            3
#define R_UART_LCR            3
#define   B_UARY_LCR_DLAB     BIT7
#define R_UART_MCR            4
#define R_UART_LSR            5
#define   B_UART_LSR_RXRDY    BIT0
#define   B_UART_LSR_TXRDY    BIT5
#define   B_UART_LSR_TEMT     BIT6
#define R_UART_MSR            6

#endif
