#
# This file contains an 'Intel Peripheral Driver' and is      
# licensed for Intel CPUs and chipsets under the terms of your
# license agreement with Intel or your vendor.  This file may 
# be modified by the user, subject to additional terms of the 
# license agreement                                           
#
#
# Copyright (c) 2008 - 2011, Intel Corporation All rights reserved
# This software and associated documentation (if any) is furnished
# under a license and may only be used or copied in accordance
# with the terms of the license. Except as permitted by such
# license, no part of this software or documentation may be
# reproduced, stored in a retrieval system, or transmitted in any
# form or by any means without the express written consent of
# Intel Corporation.
#

GCC_VER=GCC45

function Help {
    echo  Usage: "$0 [ -? | -r32 | -d32 | -clean | -buildtool]"
}

function BuildTool {
    #
    # Fix symbol links
    #
    export EDK_TOOLS_PATH=`pwd`/BaseTools
    if [ ! -d $EDK_TOOLS_PATH/Source/C/bin ]; then        
        #
        # Add execution permission
        #
        chmod +x *.sh
        chmod +x BaseTools/BuildEnv
        chmod +x BaseTools/BinWrappers/PosixLike/*
        
        if [ ! -h $EDK_TOOLS_PATH/BinWrappers/Linux-i686 ]; then
            rm -f  $EDK_TOOLS_PATH/BinWrappers/Darwin-*
            rm -f  $EDK_TOOLS_PATH/BinWrappers/Linux-*
            cd  $EDK_TOOLS_PATH/BinWrappers
            ln -fs PosixLike  Darwin-i386
            ln -fs PosixLike  Darwin-x86_64
            ln -fs PosixLike  Linux-i686
            ln -fs PosixLike  Linux-x86_64
            cd PosixLike       
            ln -fs RunToolFromSource BPDG
            ln -fs RunToolFromSource build
            ln -fs RunToolFromSource BuildEnv
            ln -fs RunToolFromSource Ecc
            ln -fs RunBinToolFromBuildDir EfiLdrImage
            ln -fs RunBinToolFromBuildDir EfiRom
            ln -fs RunToolFromSource fpd2dsc
            ln -fs RunBinToolFromBuildDir GenCrc32
            ln -fs RunToolFromSource GenFds
            ln -fs RunBinToolFromBuildDir GenFfs
            ln -fs RunBinToolFromBuildDir GenFv
            ln -fs RunBinToolFromBuildDir GenFw 
            ln -fs RunBinToolFromBuildDir GenPage
            ln -fs RunToolFromSource GenPatchPcdTable 
            ln -fs RunBinToolFromBuildDir GenSec
            ln -fs RunBinToolFromBuildDir GenVtf
            ln -fs RunBinToolFromBuildDir GnuGenBootSector
            ln -fs RunBinToolFromBuildDir LzmaCompress
            ln -fs RunToolFromSource msa2inf
            ln -fs RunToolFromSource PatchPcdValue
            ln -fs RunToolFromSource spd2dec
            ln -fs RunBinToolFromBuildDir Split
            ln -fs RunToolFromSource TargetTool
            ln -fs RunBinToolFromBuildDir TianoCompress
            ln -fs RunToolFromSource Trim
            ln -fs RunBinToolFromBuildDir VfrCompile
            ln -fs RunBinToolFromBuildDir VolInfo
            ln -fs RunBinToolFromBuildDir BootSectImage
            cd $EDK_TOOLS_PATH/..
        fi

        #
        # Create Conf folder
        #
        if [ ! -d Conf ]; then
            mkdir Conf
        fi

        #
        # Rebuild tools
        #        
        . ./edksetup.sh BaseTools
        cd BaseTools
        make clean
        make
        chmod +x Source/C/bin/*
        cd ..
    fi
}

function Clean {
    echo Removing Build and Conf directories ...    
    rm Build -rf    
    rm Conf -rf    
    rm *.log -f
    rm CedarRockPlatformPkg/features.txt -f    
    export WORKSPACE=
    export EDK_TOOLS_PATH=
}

function Prepare {
    BuildTool
    if [ ! -d Conf ]; then
        mkdir Conf
    fi
    if [ -z "$WORKSPACE" ];  then
        . ./edksetup.sh
    fi       
    chmod a+rw CedarRockPlatformPkg/Binary/Punit/*.*  -R
    if [ ! -f CedarRockPlatformPkg/features.txt ]; then
        echo \# This file is auto-generated. Do NOT edit this file. > CedarRockPlatformPkg/features.txt
        echo DEFINE    CFG_SOURCE_DEBUG = $1 >> CedarRockPlatformPkg/features.txt
    fi
}

function BuildDebug {        
    Prepare 0
    build -p CedarRockPlatformPkg/CedarRockPlatformPkg.dsc -D CFG_STATUSCODE=1 -D CFG_DEBUG=1 -b DEBUG -a IA32 -n 4 -t $GCC_VER -y ReportDebug.log
}

function BuildRelease {    
    Prepare 0  
    build -p CedarRockPlatformPkg/CedarRockPlatformPkg.dsc -b RELEASE -a IA32 -n 4 -t $GCC_VER -y ReportRelease.log
}

if   [ "$1" = "-?"  ];  then
    Help
elif [ "$1" = "-r32" ];  then 
    BuildRelease
elif [ "$1" = "-d32" ];  then 
    BuildDebug
elif [ "$1" = "-clean" ];  then 
    Clean
elif [ "$1" = "-buildtool" ];  then 
    rm -rf BaseTools/Source/C/bin
    BuildTool
else
    Help
fi
